library(bestglm)

data1 <- read.delim("Hambuckers_et_al_Forests2020_data.txt")
data1$cropxscanopy<-data1$crop*data1$scanopy

# Model selection
# For Inga vera
data2<-subset(data1,data1$species=="IV") # Change "IV" into "HT" for Helicostylis tomentosa

results<-data.frame()
for (n in 12:21){
  dc<-data2[,n]^2
  data3<-as.data.frame(cbind(data2[,n],dc,data2$scanopy,data2$crop,data2$cropxscanopy, data2$autocovariate,data2$srr))
  colnames(data3)<-c("d","dc","scanopy","crop","cropxscanopy","autocovariate","srr")
  
  bst<-bestglm(data3,family=binomial (link="logit"),weights=data2$tseeds,TopModels=5)
  
  radius<-rep(200*(n-11),5)
  bst$BestModels<-cbind(bst$BestModels,radius)
  print(paste("Radius",radius[1],"m"))
  print(bst$BestModel)
  print(bst$BestModels)
  results<-rbind(results,bst$BestModels)
                 }
results   
plot(results$radius,results$Criterion,col="red",xlab="Radius taken for forest cover (m)",ylab="BIC")
print ("Selected model")
print(results[which.min(results$Criterion),]) 

# Possibly, take the corresponding model to apply the marginality rule. 
# For Inga vera, it was the second best model which was accordingly selected
# Fitting of this model
data2$d14c<-data2$d14^2
smiv<-glm(srr~1+d14+d14c+scanopy+crop+cropxscanopy+autocovariate, weight=tseeds,family=binomial(link="logit"),data=data2)
smiv0<-glm(srr~1, weight=tseeds,family=binomial(link="logit"),data=data2)
summary(smiv)
anova(smiv0,smiv,test="LRT") #Likelihood ratio test

# Spatial autocorrelation analysis
library(lctools)
xy<-cbind(x=data2$utm1/1000,y=data2$utm2/1000) 
bws <- c(1,2,3,4,5,6,7) 
moransI.v(xy,bws,data2$srr,WType = 'Binary') # read p-values in column 6 or 8 
rp<-residuals(smiv,type="pearson")   # for Pearson residuals
moransI.v(xy,bws,rp,WType = 'Binary')

